from torusgrid import field_util

# WIP

class PFCEditor:
    def __init__(self):
        pass

    def edit(self, field):
        pass


class PFCEditAction:
    def __init__(self):
        pass


